/*
{*******************************************************************}
{                                                                   }
{       KS.CRM                                                      }
{       Customer Relationship Management                            }
{                                                                   }
{       Copyright (c) 2002 - 2013 by Kroll-Software                 }
{       All Rights Reserved                                         }
{                                                                   }
{   This code is provided 'as is',                                  }
{   without warranties of any kind. Use at your own risk.           }
{                                                                   }
{   You need a KS.CRM source-code license in order to use           }
{   these sources or portions of it.                                }
{                                                                   }
{   You must not publish, redistribute or transfer                  }
{   this source code to 3rd parties under any conditions.           }
{                                                                   }
{*******************************************************************}
*/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using KS.Common;
using KS.CRM.UI;

namespace KS.CRM.Favorites
{
    public partial class FavoritesMainViewControl : KS.CRM.UI.MainGridViewControl
    {        
        internal bool bInitializing = true;
        Dictionary<string, Image> PlugInIcons = null;

        public FavoritesMainViewControl()
            :base()
        {
            InitializeComponent();

            GRD.EditRecord += new EventHandler(GRD_EditRecord);

            this.DefaultTitle = "My Favorites";

            GRD.GRD.CellFormatting += new DataGridViewCellFormattingEventHandler(GRD_CellFormatting);

            InitToolStrip();                       

            ctxEditFavorite.Click += new EventHandler(mnuEditFavorite_Click);
            ctxEditItem.Click +=new EventHandler(GRD_EditRecord);

            GRD.SetupContextMenu += new EventHandler(GRD_SetupContextMenu);            
        }

        void GRD_SetupContextMenu(object sender, EventArgs e)
        {
            string PlugInKey = GRD.CurrentValue("PlugInKey").SafeString();
            if (PlugInKey == "")
                return;

            KS.CRM.PlugIn.KSCRMPlugIn plugin = null;

            foreach (object p in m_DB.PlugIns)
            {
                if (p is KS.CRM.PlugIn.KSCRMPlugIn)
                {
                    plugin = (KS.CRM.PlugIn.KSCRMPlugIn)p;
                    break;
                }
            }

            if (plugin == null)
                return;

            GRD.ctxEdit.Image = plugin.SmallIcon;

            GRD.ctxMenu.Items["ctxEditFavorite"].Visible = NavigationControl.CurrentDataViewKey == "Favorites";
        }        

        private void InitToolStrip()
        {
            this.GRD.AllowAddNew = false;

            this.GRD.mnuEdit.Text = Properties.Resources.menuEditItemText;
            this.GRD.mnuEdit.DisplayStyle = ToolStripItemDisplayStyle.ImageAndText;

            ToolStripButton mnuEditFavorite = new ToolStripButton(Properties.Resources.menuEditFavoriteText, Properties.Resources.favorite16);
            mnuEditFavorite.Name = "mnuEditFavorite";
            mnuEditFavorite.DisplayStyle = ToolStripItemDisplayStyle.ImageAndText;
            mnuEditFavorite.Click += new EventHandler(mnuEditFavorite_Click);
            GRD.ToolBar.Items.Insert(this.GRD.ToolBar.Items.IndexOf(this.GRD.mnuEdit) + 1, mnuEditFavorite);

            ToolStripMenuItem ctxEditFavorite = new ToolStripMenuItem(Properties.Resources.menuEditFavoriteText, Properties.Resources.favorite16);
            ctxEditFavorite.Name = "ctxEditFavorite";
            ctxEditFavorite.DisplayStyle = ToolStripItemDisplayStyle.ImageAndText;
            ctxEditFavorite.Click += new EventHandler(mnuEditFavorite_Click);
            GRD.ctxMenu.Items.Insert(GRD.ctxMenu.Items.IndexOf(GRD.ctxMenu.Items["ctxEdit"]) + 1, ctxEditFavorite);
        }        
        
        void GRD_CellFormatting(object sender, DataGridViewCellFormattingEventArgs e)
        {
            try
            {
                DataGridViewRow row = GRD.GRD.Rows[e.RowIndex];
                if (row != null && row.DataGridView.Columns.Contains("pluginkey") && row.DataGridView.Columns.Contains("DisplayName"))
                {
                    string PlugInKey = row.Cells["pluginkey"].Value.SafeString();
                    if (PlugInIcons.ContainsKey(PlugInKey))
                    {
                        ((KS.CRM.UI.Controls.DataGridViewImageTextCell)row.Cells["DisplayName"]).Image = PlugInIcons[PlugInKey];
                    }
                }            
            }
            catch (Exception)
            {                
            }            
        }        

        public override void InitData(KS.CRM.Base.CrmDatabase DB)
        {
            base.InitData(DB);            

            txtDescription.ReadOnly = true;
            txtDescription.Text = "";            

            if (m_DB.PlugIns != null)
            {
                PlugInIcons = new Dictionary<string, Image>();
                KS.CRM.PlugIn.KSCRMPlugIn PlugIn = null;

                foreach (object o in m_DB.PlugIns)
                {
                    PlugIn = (KS.CRM.PlugIn.KSCRMPlugIn)o;
                    PlugInIcons.Add(PlugIn.Key, PlugIn.SmallIcon);                    
                }
            }            
        }        

        public override bool LoadData()
        {            
            txtDescription.Enabled = true;
            return base.LoadData();
        }
        
        public override void ResetData()
        {
            base.ResetData();
            this.txtDescription.Text = "";            
        }

        public override bool Disconnect(bool QueryCanDisconnect, bool Force)
        {
            if (txtDescription != null)
            {
                this.txtDescription.Text = "";
                this.txtDescription.Enabled = false;
            }

            return base.Disconnect(QueryCanDisconnect, Force);            
        }
        
        public override bool Close()
        {
            bool ok = base.Close();

            if (PlugInIcons != null)
                PlugInIcons.Clear();

            return ok;
        }

        public override void EnableControls()
        {
            base.EnableControls();

            bool IsFavoriteView = NavigationControl.CurrentDataViewKey == "Favorites";

            GRD.AllowDelete = IsFavoriteView;            
            GRD.ToolBar.Items["mnuEditFavorite"].Visible = IsFavoriteView;            
        }

        void GRD_EditRecord(object sender, EventArgs e)
        {
            OpenRecord();
        }

        void mnuEditFavorite_Click(object sender, EventArgs e)
        {
            EditFavorite();
        }

        public override bool DeleteRecord(int ID)
        {
            switch (NavigationControl.CurrentDataViewKey)
            {
                case "Favorites":
                    return (m_DB.ExecuteUpdateSQL("Delete from Favorites where ID=" + ID.ToString()) > 0);                    

                case "Histories":                
                    return (m_DB.ExecuteUpdateSQL("Delete from Histories where ID=" + ID.ToString()) > 0);
            }

            return false;
        }

        public override void BulkDeleteRecords()
        {
            List<int> RefIDs = this.SelectedIDs;
            if (RefIDs == null || RefIDs.Count == 0)
                return;

            DeleteProgressForm Dlg = new DeleteProgressForm();

            switch (NavigationControl.CurrentDataViewKey)
            {
                case "Favorites":
                    Dlg.SetCaption(Properties.Resources.favorite16, Properties.Resources.DeleteFavoriteProgressCaption);
                    Dlg.InitData(m_DB, "Favorites", "ID", RefIDs);
                    break;

                case "Histories":                    
                    Dlg.SetCaption(Properties.Resources.favorite16, Properties.Resources.DeleteHistoryProgressCaption);
                    Dlg.InitData(m_DB, "Histories", "ID", RefIDs);
                    break;
            }            

            Dlg.ShowDialog(this);
            Dlg.Dispose();
            Dlg = null;
            RefIDs.Clear();
            GC.Collect();
            GRD.mnuRequery.PerformClick();
        }

        private void EditFavorite()
        {
            int FavoriteID = GRD.CurrentValue("ID").SafeInt();
            if (FavoriteID == 0)
                return;

            FavoriteForm Dlg = new FavoriteForm();            
            Dlg.InitData(m_DB);
            if (!Dlg.Edit(FavoriteID))
            {
                Dlg.Dispose();
                return;
            }                                   

            Dlg.ShowDialog(this);
            bool bOK = Dlg.DialogResult == DialogResult.OK;

            if (Dlg.CategoriesChanged)
                ((FavoritesNavigationControl)NavigationControl).RequeryCategories();

            Dlg.Dispose();
            Dlg = null;

            if (bOK)
            {                
                this.MoveToID(FavoriteID);             
            }
        }

        private void OpenRecord()
        {
            int RefID = GRD.CurrentValue("RefID").SafeInt();
            if (RefID == 0)
                return;

            string PlugInKey = GRD.CurrentValue("PlugInKey").SafeString();
            int TableID = GRD.CurrentValue("TableID").SafeInt();

            KS.CRM.PlugIn.KSCRMPlugIn PlugIn = null;

            bool bFound = false;

            if (m_DB.PlugIns != null)
            {
                foreach (object o in m_DB.PlugIns)
                {
                    PlugIn = (KS.CRM.PlugIn.KSCRMPlugIn)o;

                    if (PlugIn.Key == PlugInKey)
                    {
                        bFound = true;
                        break;
                    }
                }
            }

            if (bFound)
            {                
                bool bOK = PlugIn.EditRecord(RefID, this, true, null);

                if (bOK)
                {
                    switch (NavigationControl.CurrentDataViewKey)
                    {
                        case "Histories":                                                                                                                                                                                                                   
                            GRD.RequeryCurrentRow();
                            //GRD.Requery();
                            break;
                    }
                }    
            }
        }

        public override void ShowDetails()
        {
            int ID = GRD.CurrentValue("ID").SafeInt();

            switch (NavigationControl.CurrentDataViewKey)            
            {
                case "Favorites":
                    KS.CRM.Base.BL.Favorites cFavorites = new KS.CRM.Base.BL.Favorites(m_DB);

                    if (cFavorites.GetFavorite(ID))
                    {
                        this.txtDescription.Text = cFavorites.Description;
                    }
                    else
                    {
                        this.txtDescription.Text = "";
                    }
                    break;

                case "Histories":                
                    KS.CRM.Base.BL.History cHistory = new KS.CRM.Base.BL.History(m_DB);

                    if (cHistory.GetHistory(ID))
                    {
                        this.txtDescription.Text = cHistory.HistoryText;
                    }
                    else
                    {
                        this.txtDescription.Text = "";
                    }
                    break;
            }
        }        
    }
}
