/*
{*******************************************************************}
{                                                                   }
{       KS.CRM                                                      }
{       Customer Relationship Management                            }
{                                                                   }
{       Copyright (c) 2002 - 2013 by Kroll-Software                 }
{       All Rights Reserved                                         }
{                                                                   }
{   This code is provided 'as is',                                  }
{   without warranties of any kind. Use at your own risk.           }
{                                                                   }
{   You need a KS.CRM source-code license in order to use           }
{   these sources or portions of it.                                }
{                                                                   }
{   You must not publish, redistribute or transfer                  }
{   this source code to 3rd parties under any conditions.           }
{                                                                   }
{*******************************************************************}
*/

using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using KS.Common;
using KS.CRM.UI;
using KS.CRM.UI.Extensions;

namespace KS.CRM.Favorites
{
    internal class GridViewHistories : GridDataView
    {        
        public override string Caption
        {
            get
            {
                if (m_Area == 0)
                    return Properties.Resources.NavControlViewMyHistories;                    
                else
                    return Properties.Resources.NavControlViewAllHistories;
            }
        }

        public override string LoadingStatusMessage
        {
            get
            {
                return Properties.Resources.GridViewStatusLoadingHistories;
            }
        }

        public GridViewHistories(KS.CRM.Base.CrmDatabase DB, KS.CRM.UI.CrmGrid KSGrid)
            : base(DB, KSGrid, null)
        {
            QueryManager.TableName = "vwHistories";
            QueryManager.DefaultOrderBy = "HistoryDate Desc";
            //SqlQuery.PrimaryKeyColumnName = "";
        }        

        protected override string AreaWhere()
        {            
            if (m_Area == 0)
            {
                // MyHistories
                string strSQL = "(createuser='" + m_DB.CurrentUser + "')";
                strSQL += " AND ((PersonalUserID Is Null) Or (PersonalUserID = " + m_DB.UserID + "))";

                if (!m_DB.AllowViewHigherLevel)
                    strSQL += " AND (secretlevel <= " + m_DB.UserLevel + ")";

                return strSQL;
            }
            else      
            {
                // AllHistories
                if (!m_DB.AllowViewHigherLevel)
                    return "(secretlevel <= " + m_DB.UserLevel + ")";
                else
                    return "";                
            }
        }

        protected override string CategoriesSelect(string strID)
        {
            return "";            
        }

        public override void SetColumns()
        {
            this.AddIntegerColumn("TableID", "TableID", 80, false);
            this.AddIntegerColumn("RefID", "RefID", 80, false);
            this.AddTextColumn("PlugInKey", "PlugInKey", 80, false);
            
            //AddIntegerColumn("HistoryAction", "HistoryAction", "Action", 80, false);
            KS.CRM.UI.Controls.DataGridViewImageComboBoxColumn cboCol = new UI.Controls.DataGridViewImageComboBoxColumn();
            cboCol.Name = "HistoryAction";
            cboCol.HeaderText = Properties.Resources.ColumnAction;
            cboCol.DataPropertyName = "HistoryAction";

            cboCol.ImageList = ((FavoritesMainViewControl)this.m_CrmGrid.Parent).imageList1;

            cboCol.Items.Add(new KS.CRM.UI.Controls.ImageComboBoxItem(Properties.Resources.HistoryActionOther, (int)KS.CRM.Base.BL.Common.HistoryActions.Other, -1));
            cboCol.Items.Add(new KS.CRM.UI.Controls.ImageComboBoxItem(Properties.Resources.HistoryActionCall, (int)KS.CRM.Base.BL.Common.HistoryActions.Call, 0));
            cboCol.Items.Add(new KS.CRM.UI.Controls.ImageComboBoxItem(Properties.Resources.HistoryActionMailing, (int)KS.CRM.Base.BL.Common.HistoryActions.Mailing, 1));
            cboCol.Items.Add(new KS.CRM.UI.Controls.ImageComboBoxItem(Properties.Resources.HistoryActionMeeting, (int)KS.CRM.Base.BL.Common.HistoryActions.Meeting, 2));

            cboCol.DisplayMember = "Text";
            cboCol.ValueMember = "Value";
            cboCol.ValueType = typeof(int);
            cboCol.DisplayStyle = DataGridViewComboBoxDisplayStyle.Nothing;
            m_CrmGrid.GRD.Columns.Add(cboCol);


            this.AddDateTimeColumn("HistoryDate", Properties.Resources.ColumnDate, true);

            KS.CRM.UI.Controls.DataGridViewImageTextColumn colTitle = new UI.Controls.DataGridViewImageTextColumn();
            colTitle.Name = "DisplayName";
            colTitle.DataPropertyName = "DisplayName";
            colTitle.HeaderText = Properties.Resources.ColumnDisplayName;
            //colTitle.AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
            m_CrmGrid.GRD.Columns.Add(colTitle);

            //AddStandardColumn("DisplayName", "DisplayName", "Display Name", 180, true);            

            this.AddTextColumn("HistoryTitle", Properties.Resources.ColumnHistoryTitle, 240, true);
            m_CrmGrid.GRD.Columns["HistoryTitle"].AutoSizeMode = System.Windows.Forms.DataGridViewAutoSizeColumnMode.Fill;

            this.AddTextColumn("HistoryText", Properties.Resources.ColumnHistoryText, 240, false);

            this.AddIntegerColumn("PersonalUserID", "PersonalUserID", 80, false);
            this.AddDatestampColumns(false);
            this.AddIntegerColumn("secretlevel", "secretlevel", 80, false);
        }

        public override CrmSearchFormBase GetNewSearchForm()
        {
            return new HistorySearchForm();
        }
    }
}
