/*
{*******************************************************************}
{                                                                   }
{       KS.CRM                                                      }
{       Customer Relationship Management                            }
{                                                                   }
{       Copyright (c) 2002 - 2013 by Kroll-Software                 }
{       All Rights Reserved                                         }
{                                                                   }
{   This code is provided 'as is',                                  }
{   without warranties of any kind. Use at your own risk.           }
{                                                                   }
{   You need a KS.CRM source-code license in order to use           }
{   these sources or portions of it.                                }
{                                                                   }
{   You must not publish, redistribute or transfer                  }
{   this source code to 3rd parties under any conditions.           }
{                                                                   }
{*******************************************************************}
*/

using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;

namespace KS.CRM.Favorites
{
    public class PlugInFavorites : KS.CRM.PlugIn.KSCRMPlugIn
    {
        public override string Key
        {
            get
            {
                return "Favorites";
            }
        }

        public override string ParentKey
        {
            get
            {
                return "";
            }
        }

        public override string Title
        {
            get
            {
                return Properties.Resources.PlugInTitle;
            }
        }

        public override KS.CRM.PlugIn.CrmMainViewControlBase MainViewControl
        {
            get
            {
                return base.MainViewControlFactory<FavoritesMainViewControl>();
            }
        }

        public override KS.CRM.PlugIn.CrmNavigationControlBase NavigationControl
        {
            get
            {
                return base.NavigationControlFactory<FavoritesNavigationControl>();
            }
        }

        public override bool Connect(KS.CRM.Base.CrmDatabase DB)
        {
            this.m_DB = DB;

            // this order is important..
            NavigationControl.InitData(m_DB);
            MainViewControl.InitData(m_DB);

            MainViewControl.LoadData();
            NavigationControl.LoadData();            

            return true;
        }

        public override bool Disconnect(bool QueryCanDisconnect, bool Force)
        {
            NavigationControl.ResetData();
            NavigationControl.m_DB = null;
                        
            MainViewControl.ResetData();
            MainViewControl.m_DB = null;            

            this.m_DB = null;
            return true;
        }

        public override void Requery()
        {
            NavigationControl.RequeryData();
            MainViewControl.RequeryData();
        }

        public override bool Close()
        {
            NavigationControl.Close();
            MainViewControl.Close();
            return true;
        }

        public override System.Drawing.Image SmallIcon
        {
            get
            {
                return Properties.Resources.favorite16;
            }
        }

        public override System.Drawing.Image LargeIcon
        {
            get
            {
                return Properties.Resources.favorite24;
            }
        }

        public override void LoadPlugIns(KS.CRM.Base.CrmDatabase DB)
        {
            NavigationControl.LoadPlugIns(DB);
            MainViewControl.LoadPlugIns(DB);
        }        

        public override bool InvokeMethod(string Key, params object[] parameters)
        {
            if (Key.ToUpper() == "CREATEFAVORITE")
            {
                // Params:
                // 0: LinkedItemID
                // 1: LinkedItemTableID
                // 2: FavoriteTitle                

                if (parameters.Length != 3)
                {
                    KS.CRM.UI.Helpers.ErrMsgBox("Invalid number of parameters in Favorite.InvokeMethod('CreateFavorite')");
                    return false;
                }

                int LinkedItemID;
                int LinkedItemTableID;
                string FavoriteTitle;                

                try
                {
                    LinkedItemID = (int)parameters[0];
                    LinkedItemTableID = (int)parameters[1];
                    FavoriteTitle = (string)parameters[2];                
                }
                catch (Exception ex)
                {
                    KS.CRM.UI.Helpers.ErrMsgBox("Invalid parameters specified in Favorite.InvokeMethod('CreateCalendar')");
                    throw ex;
                }
                
                KS.CRM.UI.Helpers.CursorWait();

                bool bOK = false;

                FavoriteForm Dlg = new FavoriteForm();
                Dlg.InitData(m_DB);

                if (Dlg.AddFavorite(LinkedItemID, LinkedItemTableID, FavoriteTitle))
                {
                    Dlg.ShowDialog(this.MainViewControl);
                    bOK = Dlg.DialogResult == DialogResult.OK;

                    if (Dlg.DialogResult == DialogResult.OK)
                    {
                        MainViewControl.Refresh();
                    }
                }

                Dlg.Dispose();
                Dlg = null;                

                return bOK;
            }

            return false;
        }

        public override object QueryProperty(string Key, params object[] parameters)
        {
            switch (Key)
            {
                case "licensekey":
                    return "A valid license is required to use the KS.CRM.PlugIn Interface";
            }

            return null;
        }

        public override PlugIn.IKSCRMEditControl InfoControl
        {
            get
            {
                KS.CRM.UI.CrmInfoControlBase info = new InfoControl();
                info.InitPluginInfo(this);
                return info;
            }
        }

        public override string[] DependsOn()
        {
            return new string[] { "Contacts" };
        }

        public override string GetUpdateSql(string version)
        {
            //if (version == "")
            //{
            //    return Properties.Resources.SQL_Create;
            //}

            return String.Empty;
        }

        public override string GetUninstallSql()
        {
            //return Properties.Resources.SQL_Uninstall;

            return String.Empty;
        }
    }
}
